<?php

namespace Payroll\Allowance\Workflow;

use Payroll\Allowance\Models\Allowance;
use Validator;

class AllowanceValidator
{

    /**
     * Determine if the given allowance is valid for complete status.
     *
     * @param Allowance $allowance
     *
     * @return bool / Validator
     */
    public function complete(Allowance $allowance)
    {
        return Validator::make($allowance->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given allowance is valid for verify status.
     *
     * @param Allowance $allowance
     *
     * @return bool / Validator
     */
    public function verify(Allowance $allowance)
    {
        return Validator::make($allowance->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given allowance is valid for approve status.
     *
     * @param Allowance $allowance
     *
     * @return bool / Validator
     */
    public function approve(Allowance $allowance)
    {
        return Validator::make($allowance->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given allowance is valid for publish status.
     *
     * @param Allowance $allowance
     *
     * @return bool / Validator
     */
    public function publish(Allowance $allowance)
    {
        return Validator::make($allowance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given allowance is valid for archive status.
     *
     * @param Allowance $allowance
     *
     * @return bool / Validator
     */
    public function archive(Allowance $allowance)
    {
        return Validator::make($allowance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given allowance is valid for unpublish status.
     *
     * @param Allowance $allowance
     *
     * @return bool / Validator
     */
    public function unpublish(Allowance $allowance)
    {
        return Validator::make($allowance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
